aboutsummaryrefslogtreecommitdiff
path: root/backend.go
diff options
context:
space:
mode:
authorStefan Majewsky <majewsky@gmx.net>2018-05-03 15:14:47 +0200
committerStefan Majewsky <majewsky@gmx.net>2018-05-03 15:14:47 +0200
commit0e685c1a6632f2f421713f677dd1ae691dedaa68 (patch)
tree6e69cf8026523a63a71aa5f13f0ef87e2ab51f86 /backend.go
parentaf4e8d74bfe7afd4ad65eea9d6385ca969428ed6 (diff)
downloadgo-schwift-0e685c1a6632f2f421713f677dd1ae691dedaa68.tar.gz
add configurable User-Agent to Schwift, Gopherschwift
Diffstat (limited to 'backend.go')
-rw-r--r--backend.go15
1 files changed, 10 insertions, 5 deletions
diff --git a/backend.go b/backend.go
index de07015..af2c1ef 100644
--- a/backend.go
+++ b/backend.go
@@ -34,10 +34,15 @@ type Backend interface {
//the given URL. This is used by Account.SwitchAccount().
Clone(newEndpointURL string) Backend
//Do executes the given HTTP request after adding to it the X-Auth-Token
//header containing the backend's current Keystone (or Swift auth) token. It
//may also set other headers, such as User-Agent. If the status code returned
//is 401, it shall attempt to acquire a new auth token and restart the
//request with the new token.
Do(req *http.Request) (*http.Response, error)
- //TODO add UserAgent argument to Do()
}
+
+//DefaultUserAgent is the User-Agent string that Backend implementations should
+//use if the user does not provide their own User-Agent string.
+const DefaultUserAgent = "schwift/" + Version
@@ -34,10 +34,15 @@ type Backend interface {
Clone(newEndpointURL string) Backend
//Do executes the given HTTP request after adding to it the X-Auth-Token
- //header containing the backend's current Keystone (or Swift auth) token. It
- //may also set other headers, such as User-Agent. If the status code returned
- //is 401, it shall attempt to acquire a new auth token and restart the
- //request with the new token.
+ //header containing the backend's current Keystone (or Swift auth) token. If
+ //the status code returned is 401, it shall attempt to acquire a new auth
+ //token and restart the request with the new token.
+ //
+ //If the user has not supplied their own User-Agent string to the backend,
+ //the backend should use the schwift.DefaultUserAgent constant instead.
Do(req *http.Request) (*http.Response, error)